## Basic Similarities

??? info "Raw Dot Product"
    ::: similaripy.dot_product

??? info "Cosine Similarity"
    ::: similaripy.cosine

??? info "Asymmetric Cosine"
    ::: similaripy.asymmetric_cosine

??? info "Jaccard Similarity"
    ::: similaripy.jaccard

??? info "Dice Similarity"
    ::: similaripy.dice

??? info "Tversky Similarity"
    ::: similaripy.tversky

## Graph-Based Similarities

??? info "P3α"
    ::: similaripy.p3alpha

??? info "RP3β"
    ::: similaripy.rp3beta

## Hybrid Similarity

??? info "S Plus"
    ::: similaripy.s_plus